@@ -1,4 +1,3 @@
-
 /**
  * This file is part of the DOM implementation for KDE.
  *
@@ -37,7 +36,6 @@
 #include "css/css_stylesheetimpl.h"
 #include "css/cssproperties.h"
 #include "css/cssvalues.h"
-#include "css/csshelper.h"
 #include "misc/loader.h"
 #include "dom/dom_string.h"
 #include "dom/dom_doc.h"
@@ -73,7 +71,7 @@ void HTMLBodyElementImpl::parseAttribute(AttributeImpl *attr)
 
     case ATTR_BACKGROUND:
     {
-        QString url = khtml::parseURL( attr->value() ).string();
+        QString url = attr->val()->string().trimmed();
         if (!url.isEmpty()) {
             url = document()->completeURL( url );
             addCSSProperty(CSS_PROP_BACKGROUND_IMAGE, DOMString("url('"+url+"')") );
@@ -174,6 +172,14 @@ void HTMLBodyElementImpl::parseAttribute(AttributeImpl *attr)
         document()->setHTMLWindowEventListener(EventImpl::SCROLL_EVENT,
             document()->createHTMLEventListener(attr->value().string(), "onscroll", NULL));
         break;
+    case ATTR_ONMESSAGE:
+        document()->setHTMLWindowEventListener(EventImpl::MESSAGE_EVENT,
+            document()->createHTMLEventListener(attr->value().string(), "onmessage", NULL));
+        break;        
+    case ATTR_ONHASHCHANGE:
+        document()->setHTMLWindowEventListener(EventImpl::HASHCHANGE_EVENT,
+            document()->createHTMLEventListener(attr->value().string(), "onhashchange", NULL));
+        break;
     case ATTR_NOSAVE:
 	break;
     default:
@@ -247,7 +253,7 @@ HTMLFrameElementImpl::HTMLFrameElementImpl(DocumentImpl *doc)
     marginHeight = -1;
     scrolling = Qt::ScrollBarAsNeeded;
     noresize = false;
-    url = "about:blank";
+    url = QLatin1String("about:blank");;
 }
 
 HTMLFrameElementImpl::~HTMLFrameElementImpl()
@@ -319,7 +325,7 @@ void HTMLFrameElementImpl::parseAttribute(AttributeImpl *attr)
     switch(attr->id())
     {
     case ATTR_SRC:
-        setLocation(khtml::parseURL(attr->val()));
+        setLocation(attr->value().string().trimmed());
         break;
     case ATTR_FRAMEBORDER:
     {
@@ -384,7 +390,7 @@ void HTMLFrameElementImpl::attach()
     }
 
     if (parentNode()->renderer() && parentNode()->renderer()->childAllowed()
-                                 && document()->isURLAllowed(url.string()))  {
+                                 && document()->isURLAllowed(url))  {
         RenderStyle* _style = document()->styleSelector()->styleForElement(this);
         _style->ref();
         if ( _style->display() != NONE ) {
@@ -416,7 +422,7 @@ void HTMLFrameElementImpl::computeContent()
         return;
 
     // Bail out on any disallowed URLs
-    if( !document()->isURLAllowed(url.string()) )
+    if( !document()->isURLAllowed(url) )
         return;
 
     // If we have a part already, make sure it's in the right spot...
@@ -431,27 +437,29 @@ void HTMLFrameElementImpl::computeContent()
 
     // Go ahead and load a part... We don't need to clear the widget here,
     // since the -frames- have their lifetime managed, using the name uniqueness.
-    parentPart->loadFrameElement( this, url.string(), name.string() );
+    parentPart->loadFrameElement( this, url, name.string() );
 }
 
-void HTMLFrameElementImpl::setLocation( const DOMString& str )
+void HTMLFrameElementImpl::setLocation( const QString& str )
 {
     url = str;
 
-    if( !document()->isURLAllowed(url.string()) )
+    if( !document()->isURLAllowed(url) )
         return;
 
     // if we already have a child part, ask it to go there..
     KHTMLPart* childPart = contentPart();
     if ( childPart )
-        childPart->openUrl( KUrl( document()->completeURL( url.string() ) ) );
+        childPart->openUrl( KUrl( document()->completeURL( url ) ) );
     else
         setNeedComputeContent(); // otherwise, request it.. 
 }
 
-bool HTMLFrameElementImpl::isFocusable() const
+bool HTMLFrameElementImpl::isFocusableImpl(FocusType ft) const
 {
-    return m_render!=0;
+    if (m_render!=0)
+        return true;
+    return HTMLPartContainerElementImpl::isFocusableImpl(ft);
 }
 
 void HTMLFrameElementImpl::setFocus(bool received)
@@ -608,6 +616,10 @@ void HTMLFrameSetElementImpl::parseAttribute(AttributeImpl *attr)
         document()->setHTMLWindowEventListener(EventImpl::UNLOAD_EVENT,
             document()->createHTMLEventListener(attr->value().string(), "onunload", NULL));
         break;
+    case ATTR_ONMESSAGE:
+        document()->setHTMLWindowEventListener(EventImpl::MESSAGE_EVENT,
+            document()->createHTMLEventListener(attr->value().string(), "onmessage", NULL));
+        break;
     default:
         HTMLElementImpl::parseAttribute(attr);
     }
@@ -632,13 +644,15 @@ void HTMLFrameSetElementImpl::attach()
         node = static_cast<HTMLElementImpl*>(node->parentNode());
     }
 
+    RenderStyle* _style = document()->styleSelector()->styleForElement(this);
+    _style->ref();
     // ignore display: none
     if ( parentNode()->renderer() && parentNode()->renderer()->childAllowed() ) {
-        RenderStyle* _style = document()->styleSelector()->styleForElement(this);
         m_render = new (document()->renderArena()) RenderFrameSet(this);
         m_render->setStyle(_style);
         parentNode()->renderer()->addChild(m_render, nextRenderer());
     }
+    _style->deref();
 
     NodeBaseImpl::attach();
 }
@@ -741,7 +755,7 @@ void HTMLIFrameElementImpl::parseAttribute(AttributeImpl *attr )
         addHTMLAlignment( attr->value() );
         break;
     case ATTR_SRC:
-        url = khtml::parseURL(attr->val());
+        url = attr->value().string().trimmed();
         setNeedComputeContent();
         // ### synchronously start the process?
         break;
@@ -791,7 +805,7 @@ void HTMLIFrameElementImpl::attach()
 
     RenderStyle* style = document()->styleSelector()->styleForElement(this);
     style->ref();
-    if (document()->isURLAllowed(url.string()) && parentNode()->renderer()
+    if (document()->isURLAllowed(url) && parentNode()->renderer()
         && parentNode()->renderer()->childAllowed() && style->display() != NONE) {
         m_render = new (document()->renderArena()) RenderPartObject(this);
         m_render->setStyle(style);
@@ -812,7 +826,7 @@ void HTMLIFrameElementImpl::computeContent()
     if (!parentPart)
         return;
 
-    if (!document()->isURLAllowed(url.string()))
+    if (!document()->isURLAllowed(url))
         return;
 
     if (!inDocument()) {
@@ -824,10 +838,9 @@ void HTMLIFrameElementImpl::computeContent()
     ensureUniqueName();
 
     // make sure "" is handled as about: blank
-    const QString aboutBlank = QLatin1String("about:blank");
-    QString effectiveURL = url.string();
+    QString effectiveURL = url;
     if (effectiveURL.isEmpty())
-        effectiveURL = aboutBlank;
+        effectiveURL = QLatin1String("about:blank");
 
     kDebug(6031) << "-> requesting:" << name.string() << effectiveURL << contentPart();
     
