@@ -32,11 +32,9 @@
 #include "khtml_part.h"
 
 #include "misc/loader.h"
-#include "misc/helper.h"
 
 #include "css/cssstyleselector.h"
 #include "css/css_stylesheetimpl.h"
-#include "css/csshelper.h"
 #include "css/css_mediaquery.h"
 
 #include "ecma/kjs_proxy.h"
@@ -57,7 +55,7 @@ void HTMLBaseElementImpl::parseAttribute(AttributeImpl *attr)
     switch(attr->id())
     {
     case ATTR_HREF:
-	m_href = khtml::parseURL(attr->value());
+	m_href = attr->value().string().trimmed();
 	process();
 	break;
     case ATTR_TARGET:
@@ -91,7 +89,7 @@ void HTMLBaseElementImpl::process()
 	return;
 
     if(!m_href.isEmpty() && document()->part())
-	document()->setBaseURL( KUrl( document()->part()->url(), m_href.string() ) );
+	document()->setBaseURL( KUrl( document()->part()->url(), m_href ) );
 
     if(!m_target.isEmpty())
 	document()->setBaseTarget( m_target.string() );
@@ -117,10 +115,14 @@ void HTMLLinkElementImpl::parseAttribute(AttributeImpl *attr)
 {
     switch (attr->id())
     {
-    case ATTR_HREF:
-        m_url = document()->completeURL( khtml::parseURL(attr->value()).string() );
-	process();
+    case ATTR_HREF: {
+        const QString hrefUrl = attr->val()->string().trimmed();
+        if (!hrefUrl.isEmpty()) {
+            m_url = document()->completeURL(hrefUrl);
+        }
+        process();
         break;
+    }
     case ATTR_REL:
     case ATTR_TYPE:
 	process();
@@ -183,11 +185,10 @@ void HTMLLinkElementImpl::process()
 
     // IE extension: location of small icon for locationbar / bookmarks
     // Uses both "shortcut icon" and "icon"
-    if ( part && rel.contains("icon") && !m_url.isEmpty() && !part->parentPart())
+    if (rel.contains("icon") && !m_url.isEmpty() && part && !part->parentPart()) {
         part->browserExtension()->setIconUrl( KUrl(m_url.string()) );
-
-    // Stylesheet
-    else if (!m_isDisabled && rel.contains("stylesheet")) {
+    } // Stylesheet
+    else if (rel.contains("stylesheet") && !m_url.isEmpty() && !m_isDisabled) {
         // no need to load style sheets which aren't for the screen output
         // ### there may be in some situations e.g. for an editor or script to manipulate
         khtml::MediaQueryEvaluator allEval(true);
@@ -384,7 +385,7 @@ void HTMLScriptElementImpl::parseAttribute(AttributeImpl *attr)
         // we'll only start doing things once we get insertedIntoDocument()
         if (m_evaluated || m_cachedScript || m_createdByParser || !inDocument())
             return;
-        DOMString url = attr->value();
+        QString url = attr->value().string().trimmed();
         if (!url.isEmpty())
             loadFromUrl(url);
         break;
@@ -489,7 +490,7 @@ void HTMLScriptElementImpl::insertedIntoDocument()
     if (m_createdByParser)
         return;
 
-    DOMString url = getAttribute(ATTR_SRC).string();
+    QString url = getAttribute(ATTR_SRC).string().trimmed();
     if (!url.isEmpty()) {
         loadFromUrl(url);
         return;
@@ -621,7 +622,7 @@ void HTMLScriptElementImpl::setDefer(bool defer)
 
 DOMString HTMLScriptElementImpl::src() const
 {
-    return document()->completeURL(getAttribute(ATTR_SRC).string());
+    return document()->completeURL(getAttribute(ATTR_SRC).string().trimmed());
 }
 
 void HTMLScriptElementImpl::setSrc(const DOMString &value)
@@ -795,17 +796,15 @@ void HTMLTitleElementImpl::setText( const DOMString& str )
 {
     int exceptioncode = 0;
     // Look for an existing text child node
-    DOM::NodeListImpl* nl(childNodes());
-    if (nl)
-    {
-        for (unsigned int i = 0; i < nl->length(); i++) {
-            if (nl->item(i)->nodeType() == DOM::Node::TEXT_NODE) {
-                static_cast<DOM::TextImpl *>(nl->item(i))->setData(str, exceptioncode);
-                return;
+    RefPtr<DOM::NodeListImpl> nl = childNodes();
+    const unsigned int length = nl->length();
+    for (unsigned int i = 0; i < length; ++i) {
+        if (nl->item(i)->nodeType() == DOM::Node::TEXT_NODE) {
+            static_cast<DOM::TextImpl *>(nl->item(i))->setData(str, exceptioncode);
+            return;
             }
-        }
-        delete nl;
     }
+
     // No child text node found, creating one
     DOM::TextImpl* t = document()->createTextNode(str.implementation());
     appendChild(t, exceptioncode);
