@@ -40,7 +40,6 @@
 
 #include "xml/dom_docimpl.h"
 #include "css/cssstyleselector.h"
-#include "css/csshelper.h"
 #include "css/cssproperties.h"
 #include "css/cssvalues.h"
 #include "rendering/render_frames.h"
@@ -507,12 +506,6 @@ void HTMLObjectBaseElementImpl::computeContent()
         KHTMLPart* p = document()->part();
         if (!p || !p->javaEnabled())
             newRenderAlternative = true;
-    } else {    
-        // Similarly for plugins.
-        KHTMLPart* p = document()->part();
-
-        if (!p || !p->pluginsEnabled())
-            newRenderAlternative = true;
     }
 
     // If there is no <embed> (here or as a child), and we don't have a type + url to go on,
@@ -702,7 +695,7 @@ void HTMLEmbedElementImpl::parseAttribute(AttributeImpl *attr)
   {
      case ATTR_CODE:
      case ATTR_SRC:
-         url = khtml::parseURL(attr->val()).string();
+         url = attr->val()->string().trimmed();
          setNeedComputeContent();
          break;
      case ATTR_BORDER:
@@ -782,7 +775,7 @@ void HTMLObjectElementImpl::parseAttribute(AttributeImpl *attr)
   switch ( attr->id() )
   {
     case ATTR_DATA:
-      url = khtml::parseURL( attr->val() ).string();
+      url = attr->val()->string().trimmed();
       setNeedComputeContent();
       break;
     case ATTR_CLASSID:
