@@ -32,14 +32,12 @@
 #include <dom/dom_exception.h>
 #include <dom/dom_node.h>
 
-#include <misc/htmlhashes.h>
 #include <khtmlview.h>
 #include <khtml_part.h>
 
 #include <css/cssstyleselector.h>
 #include <css/cssproperties.h>
 #include <css/cssvalues.h>
-#include <css/csshelper.h>
 
 #include <rendering/render_table.h>
 
@@ -497,8 +495,8 @@ void HTMLTableElementImpl::parseAttribute(AttributeImpl *attr)
         break;
     case ATTR_BACKGROUND:
     {
-        if (!attr->value().isEmpty()) {
-            QString url = khtml::parseURL( attr->value() ).string();
+        QString url = attr->val()->string().trimmed();
+        if (!url.isEmpty()) {
             url = document()->completeURL( url );
             addCSSProperty(CSS_PROP_BACKGROUND_IMAGE, DOMString("url('"+url+"')") );
         }
@@ -640,8 +638,8 @@ void HTMLTablePartElementImpl::parseAttribute(AttributeImpl *attr)
         break;
     case ATTR_BACKGROUND:
     {
-        if (attr->val()) {
-            QString url = khtml::parseURL( attr->value() ).string();
+        QString url = attr->val()->string().trimmed();
+        if (!url.isEmpty()) {
             url = document()->completeURL( url );
             addCSSProperty(CSS_PROP_BACKGROUND_IMAGE,  DOMString("url('"+url+"')") );
         }
