@@ -119,7 +119,7 @@ void ProspectiveTokenizer::reset()
     m_lastStartTag.clear();
     m_lastStartTagId = 0;
     
-    m_urlToLoad = "";
+    m_urlToLoad = DOMString();
     m_linkIsStyleSheet = false;
     m_lastCharacterIndex = 0;
     clearLastCharacters();
@@ -706,7 +706,7 @@ void ProspectiveTokenizer::processAttribute()
         LocalName attrLocal = LocalName::fromString(&attrDS, IDS_NormalizeLower);
         uint attribute = attrLocal.id();
         if (attribute == localNamePart(ATTR_SRC) && m_urlToLoad.isEmpty())
-            m_urlToLoad = parseURL(DOMString(m_attributeValue.data(), m_attributeValue.size()));
+            m_urlToLoad = DOMString(QString(m_attributeValue.data(), m_attributeValue.size()).trimmed());
         break;
     }
     case ID_LINK:
@@ -715,7 +715,7 @@ void ProspectiveTokenizer::processAttribute()
         LocalName attrLocal = LocalName::fromString(&attrDS, IDS_NormalizeLower);
         uint attribute = attrLocal.id();
         if (attribute == localNamePart(ATTR_HREF) && m_urlToLoad.isEmpty())
-            m_urlToLoad = parseURL(DOMString(m_attributeValue.data(), m_attributeValue.size()));
+            m_urlToLoad = DOMString(QString(m_attributeValue.data(), m_attributeValue.size()).trimmed());
         else if (attribute == localNamePart(ATTR_REL)) {
             DOMStringImpl* lowerAttribute = DOMStringImpl(DOMStringImpl::ShallowCopy, m_attributeValue.data(), m_attributeValue.size()).lower();
             QString val = lowerAttribute->string();
@@ -878,8 +878,9 @@ void ProspectiveTokenizer::emitCSSRule()
     if (rule.toLower() == "import" && !m_cssRuleValue.isEmpty()) {
         DOMString value = DOMString(m_cssRuleValue.data(), m_cssRuleValue.size());
         DOMString url = parseURL(value);
-        if (!url.isEmpty())
-            m_document->docLoader()->registerPreload( m_document->docLoader()->requestStyleSheet( m_urlToLoad, m_document->part()->encoding() ) ); // #### charset
+        if (!url.isEmpty()) {
+            m_document->docLoader()->registerPreload(m_document->docLoader()->requestStyleSheet(url, m_document->part()->encoding())); // #### charset
+        }
     }
     m_cssRule.clear();
     m_cssRuleValue.clear();
