@@ -34,8 +34,6 @@
 #include <kdebug.h>
 #include <kglobalsettings.h>
 
-#include "css/csshelper.h"
-#include "misc/helper.h"
 #include "misc/loader.h"
 #include "html/html_formimpl.h"
 #include "html/html_imageimpl.h"
@@ -217,6 +215,9 @@ void RenderImage::paint(PaintInfo& paintInfo, int _tx, int _ty)
     if(shouldPaintBackgroundOrBorder())
         paintBoxDecorations(paintInfo, _tx, _ty);
 
+    if (!canvas()->printImages())
+        return;
+
     int cWidth = contentWidth();
     int cHeight = contentHeight();
     int leftBorder = borderLeft();
@@ -224,9 +225,6 @@ void RenderImage::paint(PaintInfo& paintInfo, int _tx, int _ty)
     int leftPad = paddingLeft();
     int topPad = paddingTop();
 
-    if (!canvas()->printImages())
-        return;
-
     // paint frame around image and loading icon as long as it is not completely loaded from web.
     if (bUnfinishedImageFrame && paintInfo.phase == PaintActionForeground && cWidth > 2 && cHeight > 2 && !complete()) {
         static QPixmap *loadingIcon;
@@ -368,7 +366,6 @@ void RenderImage::layout()
     KHTMLAssert( minMaxKnown() );
 
     //short m_width = 0;
-    int m_height;
 
     // minimum height
     m_height = m_cachedImage && m_cachedImage->isErrorImage() ? intrinsicHeight() : 0;
@@ -430,16 +427,20 @@ void RenderImage::updateFromElement()
     else if (element()->id() == ID_IMG)
         alt = static_cast<HTMLImageElementImpl*>(element())->altText();
 
-    DOMString u = element()->id() == ID_OBJECT ?
-                  element()->getAttribute(ATTR_DATA) : element()->getAttribute(ATTR_SRC);
+    const QString u = element()->id() == ID_OBJECT ?
+                  element()->getAttribute(ATTR_DATA).string().trimmed() : element()->getAttribute(ATTR_SRC).string().trimmed();
 
-    if (!u.isEmpty() &&
-        ( !m_cachedImage || m_cachedImage->url() != u ) ) {
-        CachedImage *new_image = element()->document()->docLoader()->
-                                 requestImage(khtml::parseURL(u));
-
-        if(new_image && new_image != m_cachedImage)
-            updateImage( new_image );
+    if (!u.isEmpty()) {
+        // Need to compute completeURL, as 'u' can be relative
+        // while m_cachedImage->url() is always full url
+        DocumentImpl *docImpl = element()->document();
+        const QString fullUrl = docImpl->completeURL(u);
+        if (!m_cachedImage || m_cachedImage->url() != fullUrl) {
+            CachedImage *new_image = docImpl->docLoader()->requestImage(fullUrl);
+            if (new_image && new_image != m_cachedImage) {
+                updateImage(new_image);
+            }
+        }
     }
 }
 
