@@ -37,10 +37,8 @@
 #include <html/htmltokenizer.h>
 #include "dom_restyler.h"
 
-#include <css/csshelper.h>
 #include <css/cssstyleselector.h>
 #include <css/css_stylesheetimpl.h>
-#include <misc/helper.h>
 #include <misc/seed.h>
 #include <misc/loader.h>
 #include <ecma/kjs_proxy.h>
@@ -1409,25 +1407,14 @@ void DocumentImpl::recalcStyle( StyleChange change )
         RenderStyle* _style = new RenderStyle();
         _style->setDisplay(BLOCK);
         _style->setVisuallyOrdered( visuallyOrdered );
-        // ### make the font stuff _really_ work!!!!
+        // ### make the font stuff _really_ work!!!! (??)
 
-	khtml::FontDef fontDef;
-	QFont f = KGlobalSettings::generalFont();
-	fontDef.family = f.family();
-	fontDef.italic = f.italic();
-	fontDef.weight = f.weight();
-        if (m_view) {
-            const KHTMLSettings *settings = m_view->part()->settings();
-	    QString stdfont = settings->stdFontName();
-	    if ( !stdfont.isEmpty() )
-		fontDef.family = stdfont;
-
-            fontDef.size = m_styleSelector->fontSizes()[3];
-        }
-
-        //kDebug() << "DocumentImpl::attach: setting to charset " << settings->charset();
+        FontDef fontDef = FontDef();
+        // Initial fontDef.size is 0
+        fontDef.size = m_styleSelector->fontSizes()[3];
         _style->setFontDef(fontDef);
-	_style->htmlFont().update( 0 );
+        _style->htmlFont().update(0);
+
         if ( inCompatMode() )
             _style->setHtmlHacks(true); // enable html specific rendering tricks
 
@@ -1997,11 +1984,10 @@ void DocumentImpl::processHttpEquiv(const DOMString &equiv, const DOMString &con
             if(str.indexOf("url", 0, Qt::CaseInsensitive ) == 0)  str = str.mid(3);
             str = str.trimmed();
             if ( str.length() && str[0] == '=' ) str = str.mid( 1 ).trimmed();
-            while(str.length() &&
-                  (str[str.length()-1] == ';' || str[str.length()-1] == ','))
+            while (str.length() && (str[str.length()-1] == ';' || str[str.length()-1] == ',')) {
                 str.resize(str.length()-1);
-            str = parseURL( DOMString(str) ).string();
-            QString newURL = document()->completeURL( str );
+            }
+            QString newURL = document()->completeURL(str.trimmed());
             if ( ok )
                 v->part()->scheduleRedirection(delay, newURL,  delay < 2 || newURL == URL().url());
         }
@@ -2061,8 +2047,8 @@ bool DocumentImpl::prepareMouseEvent( bool readonly, int _x, int _y, MouseEvent
             //qDebug("urlnode: %s  (%d)", getTagName(renderInfo.URLElement()->id()).string().toLatin1().constData(), renderInfo.URLElement()->id());
 
             ElementImpl* e =  static_cast<ElementImpl*>(renderInfo.URLElement());
-            DOMString href = khtml::parseURL(e->getAttribute(ATTR_HREF));
-            DOMString target = e->getAttribute(ATTR_TARGET);
+            const DOMString href = e->getAttribute(ATTR_HREF).string().trimmed();
+            const DOMString target = e->getAttribute(ATTR_TARGET);
 
             if (!target.isNull() && !href.isNull()) {
                 ev->target = target;
